==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/users/language/ro.php <==
<?php


$l['name'] = 'Utilizatori';
$l['description'] = 'Modul Admin; Gestione sistemul utilizatori.';
$l['deletePrimaryAdmin'] = 'Nu poţi şterge administratorul principal';
$l['deleteYourself'] = 'Nu te poţi şterge pe tine insăţi';
$link_type[8]=$us_user = 'Utilizator';
$l['error_username']='Sunt caractere invalide in numele utilizatorului';
$l['error_username_exists']='Nume utilizator există deja';
$l['error_email_exists']='Adresa email deja folosită. Poţi folosi sistemul de amintire a parolei pentru a recupera parola.';
$l['error_match_pass']='Parola este eronată';
$l['error_email']='Adresa e-mail nu este corectă';
$l['imported']='importaţi %s utilizatori';
$l['failed']='Eroare';
$l['incorrectFormat']='Fişierul nu este în formatul CSV corect';﻿;
$l["cmdCheckColumnRead"]= 'Citire';
$l["cmdCheckColumnWrite"]= 'Scriere';
$l["cmdHeaderColumnName"]= 'Numele modulului';
$l["cmdHeaderGridUserHasAccess"]= 'utilizatorul are acces la';
$l["cmdHeaderGridUserIsMemberOf"]= 'Utilizatorul este membru de';
$l["cmdHeaderGridUserVisibleTo"]= 'Utilizatorul este vizibil la';
$l["cmdPanelPersonal"]= 'Personal';
$l["cmdPanelPassword"]= 'Parola';
$l["cmdPanelCompany"]= 'Firmă';
$l["cmdPanelPermissions"]= 'Permis';
$l["cmdPanelLogin"]= 'Acces';
$l["cmdPanelLookFeel"]= 'Look & Feel';
$l["cmdPanelSettings"]= 'Impostari';
$l["cmdPanelEnabledMail"]= 'E-mail pentru noi utilizatori abilitaţi';
$l["cmdPanelDisabledMail"]= 'E-mail pentru noi utilizzatori neabilitaţi';
$l["cmdFieldSetPersonal"]= 'Personal';	;
$l["cmdUserWindowTitle"]= 'Modifică utilizator';
$l["cmdNotificationWindowTitle"]= 'Modifică e-mail pentru invitaţia utilizatorului';
$l["cmdMaskSaving"]= 'Salvare';
$l["cmdFormLabelSubject"]= 'Obiect';
$l["cmdFormLabelUsername"]= 'Nume';
$l["cmdFormLabelName"]= 'Nume';
$l["cmdFormLabelPassword"]= 'Parola';
$l["cmdFormLabelConfirm"]= 'Confirmă';
$l["cmdBoxLabelEnabled"]= 'Abilitează';
$l["cmdFormLabelHomepage"]= 'Homepage';
$l["cmdFormLabelRegistrationTime"]= 'Timp de înregistrare';
$l["cmdFormLabelLastLogin"]= 'Ultimul acces';
$l["cmdFormLabelTotalLogins"]= 'Accese totale';
$l["numberOfLogins"]= 'Număr de accese';
$l["cmdFormLabelTheme"]= 'Temă';
$l["cmdFormLabelStartModule"]= 'Start în modul';
$l["cmdFormLabelMaximunRows"]= 'Numărul maxim de linii in liste';
$l["cmdFormLabelSortNamesBy"]= 'Prenume';
$l["cmdFormLabelLanguage"]= 'Limbă';
$l["cmdFormLabelTimezone"]= 'Fus orar';
$l["cmdFormLabelAdjustDaylight"]= 'Treci automatic la ora legală';
$l["cmdFormLabelDateFormat"]= 'Format dată';
$l["cmdFormLabelDateSeperator"]= 'Separator dată';
$l["timeFormat"]= 'Format timp';
$l["cmdFormLabelFirstWeekday"]= 'Prima zi a săptămânii';
$l["cmdFormLabelThousandSeperator"]= 'Separator de mii';
$l["cmdFormLabelDecimalSeperator"]= 'Separator de zecimi';
$l["cmdFormLabelCurrency"]= 'Valută';
$l["account"]= 'Cont';
$l["confirmPassword"]= 'Confirmă password';
$l["companyProfile"]= 'Profil firmă';
$l["loginInfo"]= 'Informaţii despre acces';
$l["changePassword"]= 'Modifică parola';
$l["currentPassword"]= 'Parola actuală';
$l["newPassword"]= 'Nouă parolă';
$l["confirmPassword"]= 'Confirmă parola';
$l["moduleAccess"]= 'Modul de acces';
$l["groupMembership"]= 'Membru al grupului';
$l["personalProfile"]= 'Profil personal';
$l["settings"]= 'Setări personale';
$l["dmy"]= 'Ziuă-Lună-An';
$l["mdy"]= 'Lună-Ziuă-An';
$l["jmd"]= 'An-Lună-Ziuă';
$l["fullhourformat"]= 'Format 24 ore';
$l["halfhourformat"]= 'Format 12 ore';
$l["sunday"]= 'Duminică';
$l["monday"]= 'Luni';
$l["regionalSettings"]= 'Setări regionale';
$l["userSettings"]= 'Setări utilizator';
$l["maxUsersReached"]='Numărul maxim de utilizzatori a fost ajuns. Se poate mări numărul de utilizatori în dosarul de servicii.';
$l["group"]='Grup';
$l["userIsMemberOf"]= 'Utilizatorul e membru de';
$l["userVisibleTo"]= 'Utilizatorul e vizibil de la';
$l["muteSound"]='Mut';
$l["downloadSampleCSV"]='Descarcă CSV din exemplul';
$l["importText"]='Poţi importa utilizzatori utiliznd un dosar CSV. Pentru a ști cum dosarul CSV trebuie formatat descarcă dosarul din exemplul.<br />Prima linie trebuie să conţină numele coloanelor. Câmpurile obligatorii pentru fiecare utilizator sunt:<br /><br />username, password, first_name, last_name, email';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/users/language/ro.php <==
<?php


$l['name'] = 'Utilizatori';
$l['description'] = 'Modul Admin; Gestione sistemul utilizatori.';
$l['deletePrimaryAdmin'] = 'Nu poţi şterge administratorul principal';
$l['deleteYourself'] = 'Nu te poţi şterge pe tine insăţi';
$link_type[8]=$us_user = 'Utilizator';
$l['error_username']='Sunt caractere invalide in numele utilizatorului';
$l['error_username_exists']='Nume utilizator există deja';
$l['error_email_exists']='Adresa email deja folosită. Poţi folosi sistemul de amintire a parolei pentru a recupera parola.';
$l['error_match_pass']='Parola este eronată';
$l['error_email']='Adresa e-mail nu este corectă';
$l['imported']='importaţi %s utilizatori';
$l['failed']='Eroare';
$l['incorrectFormat']='Fişierul nu este în formatul CSV corect';;
$l["cmdCheckColumnRead"]= 'Citire';
$l["cmdCheckColumnWrite"]= 'Scriere';
$l["cmdHeaderColumnName"]= 'Numele modulului';
$l["cmdHeaderGridUserHasAccess"]= 'utilizatorul are acces la';
$l["cmdHeaderGridUserIsMemberOf"]= 'Utilizatorul este membru de';
$l["cmdHeaderGridUserVisibleTo"]= 'Utilizatorul este vizibil la';
$l["cmdPanelPersonal"]= 'Personal';
$l["cmdPanelPassword"]= 'Parola';
$l["cmdPanelCompany"]= 'Firmă';
$l["cmdPanelPermissions"]= 'Permis';
$l["cmdPanelLogin"]= 'Acces';
$l["cmdPanelLookFeel"]= 'Look & Feel';
$l["cmdPanelSettings"]= 'Impostari';
$l["cmdPanelEnabledMail"]= 'E-mail pentru noi utilizatori abilitaţi';
$l["cmdPanelDisabledMail"]= 'E-mail pentru noi utilizzatori neabilitaţi';
$l["cmdFieldSetPersonal"]= 'Personal';	;
$l["cmdUserWindowTitle"]= 'Modifică utilizator';
$l["cmdNotificationWindowTitle"]= 'Modifică e-mail pentru invitaţia utilizatorului';
$l["cmdMaskSaving"]= 'Salvare';
$l["cmdFormLabelSubject"]= 'Obiect';
$l["cmdFormLabelUsername"]= 'Nume';
$l["cmdFormLabelName"]= 'Nume';
$l["cmdFormLabelPassword"]= 'Parola';
$l["cmdFormLabelConfirm"]= 'Confirmă';
$l["cmdBoxLabelEnabled"]= 'Abilitează';
$l["cmdFormLabelHomepage"]= 'Homepage';
$l["cmdFormLabelRegistrationTime"]= 'Timp de înregistrare';
$l["cmdFormLabelLastLogin"]= 'Ultimul acces';
$l["cmdFormLabelTotalLogins"]= 'Accese totale';
$l["numberOfLogins"]= 'Număr de accese';
$l["cmdFormLabelTheme"]= 'Temă';
$l["cmdFormLabelStartModule"]= 'Start în modul';
$l["cmdFormLabelMaximunRows"]= 'Numărul maxim de linii in liste';
$l["cmdFormLabelSortNamesBy"]= 'Prenume';
$l["cmdFormLabelLanguage"]= 'Limbă';
$l["cmdFormLabelTimezone"]= 'Fus orar';
$l["cmdFormLabelAdjustDaylight"]= 'Treci automatic la ora legală';
$l["cmdFormLabelDateFormat"]= 'Format dată';
$l["cmdFormLabelDateSeperator"]= 'Separator dată';
$l["timeFormat"]= 'Format timp';
$l["cmdFormLabelFirstWeekday"]= 'Prima zi a săptămânii';
$l["cmdFormLabelThousandSeperator"]= 'Separator de mii';
$l["cmdFormLabelDecimalSeperator"]= 'Separator de zecimi';
$l["cmdFormLabelCurrency"]= 'Valută';
$l["account"]= 'Cont';
$l["confirmPassword"]= 'Confirmă password';
$l["companyProfile"]= 'Profil firmă';
$l["loginInfo"]= 'Informaţii despre acces';
$l["changePassword"]= 'Modifică parola';
$l["currentPassword"]= 'Parola actuală';
$l["newPassword"]= 'Nouă parolă';
$l["confirmPassword"]= 'Confirmă parola';
$l["moduleAccess"]= 'Modul de acces';
$l["groupMembership"]= 'Membru al grupului';
$l["personalProfile"]= 'Profil personal';
$l["settings"]= 'Setări personale';
$l["dmy"]= 'Ziuă-Lună-An';
$l["mdy"]= 'Lună-Ziuă-An';
$l["jmd"]= 'An-Lună-Ziuă';
$l["fullhourformat"]= 'Format 24 ore';
$l["halfhourformat"]= 'Format 12 ore';
$l["sunday"]= 'Duminică';
$l["monday"]= 'Luni';
$l["regionalSettings"]= 'Setări regionale';
$l["userSettings"]= 'Setări utilizator';
$l["maxUsersReached"]='Numărul maxim de utilizzatori a fost ajuns. Se poate mări numărul de utilizatori în dosarul de servicii.';
$l["group"]='Grup';
$l["userIsMemberOf"]= 'Utilizatorul e membru de';
$l["userVisibleTo"]= 'Utilizatorul e vizibil de la';
$l["muteSound"]='Mut';
$l["downloadSampleCSV"]='Descarcă CSV din exemplul';
$l["importText"]='Poţi importa utilizzatori utiliznd un dosar CSV. Pentru a ști cum dosarul CSV trebuie formatat descarcă dosarul din exemplul.<br />Prima linie trebuie să conţină numele coloanelor. Câmpurile obligatorii pentru fiecare utilizator sunt:<br /><br />username, password, first_name, last_name, email';
